@@ -13,14 +13,15 @@ require HTML::DOM::Element;
 require HTML::DOM::NodeList::Magic;
 #require HTML::DOM::Collection::Elements;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::Element HTML::Form';
 
 use overload fallback => 1,
 '@{}' => sub { shift->elements },
 '%{}' => sub {
 	my $self = shift;
-	$self->isa(scalar caller) and return $self;
+	$self->isa(scalar caller) || caller->isa('HTML::TreeBuilder')
+		and return $self;
 	$self->elements;
 };
 
@@ -200,7 +201,7 @@ package HTML::DOM::NodeList::Radio; # solely for HTML::Form compatibility
 use Carp 'croak';
 require HTML::DOM::NodeList;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::NodeList HTML::Form::Input';
 
 sub type { 'radio' }
@@ -282,7 +283,7 @@ use warnings;
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 require HTML::DOM::Collection;
 our @ISA = 'HTML::DOM::Collection';
@@ -456,7 +457,7 @@ L<HTML::Form>
 # ------- HTMLSelectElement interface ---------- #
 
 package HTML::DOM::Element::Select;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = 'HTML::DOM::Element';
 
 sub type      { shift->attr('type') }
@@ -522,7 +523,7 @@ package HTML::DOM::Collection::Options;
 use strict;
 use warnings;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Carp 'croak';
 
@@ -596,7 +597,7 @@ sub form_name_value
 # ------- HTMLOptGroupElement interface ---------- #
 
 package HTML::DOM::Element::OptGroup;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = 'HTML::DOM::Element';
 
 sub label  { shift->attr( label => @_) }
@@ -606,7 +607,7 @@ sub label  { shift->attr( label => @_) }
 # ------- HTMLOptionElement interface ---------- #
 
 package HTML::DOM::Element::Option;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::Element HTML::Form::Input';
 
 use Carp 'croak';
@@ -728,7 +729,7 @@ sub form_name_value
 # ------- HTMLInputElement interface ---------- #
 
 package HTML::DOM::Element::Input;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -912,7 +913,7 @@ sub content {
 # ------- HTMLTextAreaElement interface ---------- #
 
 package HTML::DOM::Element::TextArea;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::Element HTML::Form::Input';
 
 sub defaultValue { # same as HTML::DOM::Element::Title::text
@@ -966,7 +967,7 @@ sub form_name_value
 # ------- HTMLButtonElement interface ---------- #
 
 package HTML::DOM::Element::Button;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -980,7 +981,7 @@ our @ISA = qw'HTML::DOM::Element';
 # ------- HTMLLabelElement interface ---------- #
 
 package HTML::DOM::Element::Label;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -990,7 +991,7 @@ sub htmlFor { shift->attr( htmlFor       => @_) }
 # ------- HTMLFieldSetElement interface ---------- #
 
 package HTML::DOM::Element::FieldSet;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -998,7 +999,7 @@ our @ISA = qw'HTML::DOM::Element';
 # ------- HTMLLegendElement interface ---------- #
 
 package HTML::DOM::Element::Legend;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
